# Load the helper function and call it with arguments tailored for the local
# grid.  It will make the morph configuration for us.  We share this function
# with the production grid and have one fewer possible point of divergence.
import ../../lib/make-grid.nix {
  name = "LocalDev";
  config = ./config.json;
  nodes = cfg:
  let
    sshUsers = import ./users.nix;
    vpnClientIPs = [ "172.23.23.11" "172.23.23.12" "172.23.23.13" ]; # TBD: derive automatically
    # Get vpn key folder relative to current dir, as a string:
    monitoringvpnKeyDir = toString ./. + "/${cfg.monitoringvpnKeyFolder}";
  in {
    "payments1" = import ../../lib/make-issuer.nix (rec {
      publicIPv4 = "192.168.67.21";
      monitoringvpnIPv4 = "172.23.23.11";
      inherit monitoringvpnKeyDir;
      inherit sshUsers;
      hardware = import ./virtual-hardware.nix ({ inherit publicIPv4; });
      stateVersion = "19.03";
    } // cfg);

    "storage1" = import ../../lib/make-testing.nix (rec {
      publicIPv4 = "192.168.67.22";
      monitoringvpnIPv4 = "172.23.23.12";
      inherit monitoringvpnKeyDir;
      inherit sshUsers;
      hardware = import ./virtual-hardware.nix ({ inherit publicIPv4; });
      stateVersion = "19.09";
    } // cfg);

    "storage2" = import ../../lib/make-testing.nix (rec {
      publicIPv4 = "192.168.67.23";
      monitoringvpnIPv4 = "172.23.23.13";
      inherit monitoringvpnKeyDir;
      inherit sshUsers;
      hardware = import ./virtual-hardware.nix ({ inherit publicIPv4; });
      stateVersion = "19.09";
    } // cfg);

    "monitoring1" = import ../../lib/make-monitoring.nix (rec {
      publicIPv4 = "192.168.67.24";
      monitoringvpnIPv4 = "172.23.23.1";
      inherit vpnClientIPs;
      inherit sshUsers;
      inherit monitoringvpnKeyDir;
      hardware = import ./virtual-hardware.nix ({ inherit publicIPv4; });
      stateVersion = "19.09";
    } // cfg);
  };
}
